@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -198,6 +200,46 @@ Col<eT>::Col(const SizeMat& s, const fill::fill_class<fill_type>& f)
 
 
 
+template<typename eT>
+inline
+Col<eT>::Col(const uword in_n_elem, const fill::scalar_holder<eT> f)
+  : Mat<eT>(arma_vec_indicator(), in_n_elem, 1, 1)
+  {
+  arma_extra_debug_sigprint();
+  
+  (*this).fill(f.scalar);
+  }
+
+
+
+template<typename eT>
+inline
+Col<eT>::Col(const uword in_n_rows, const uword in_n_cols, const fill::scalar_holder<eT> f)
+  : Mat<eT>(arma_vec_indicator(), 0, 0, 1)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::init_warm(in_n_rows, in_n_cols);
+  
+  (*this).fill(f.scalar);
+  }
+
+
+
+template<typename eT>
+inline
+Col<eT>::Col(const SizeMat& s, const fill::scalar_holder<eT> f)
+  : Mat<eT>(arma_vec_indicator(), 0, 0, 1)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::init_warm(s.n_rows, s.n_cols);
+  
+  (*this).fill(f.scalar);
+  }
+
+
+
 template<typename eT>
 inline
 Col<eT>::Col(const char* text)
@@ -594,6 +636,7 @@ Col<eT>::operator<<(const eT val)
 
 template<typename eT>
 arma_inline
+arma_warn_unused
 const Op<Col<eT>,op_htrans>
 Col<eT>::t() const
   {
@@ -604,6 +647,7 @@ Col<eT>::t() const
 
 template<typename eT>
 arma_inline
+arma_warn_unused
 const Op<Col<eT>,op_htrans>
 Col<eT>::ht() const
   {
@@ -614,6 +658,7 @@ Col<eT>::ht() const
 
 template<typename eT>
 arma_inline
+arma_warn_unused
 const Op<Col<eT>,op_strans>
 Col<eT>::st() const
   {
@@ -624,6 +669,7 @@ Col<eT>::st() const
 
 template<typename eT>
 arma_inline
+arma_warn_unused
 const Op<Col<eT>,op_strans>
 Col<eT>::as_row() const
   {
@@ -1232,6 +1278,19 @@ Col<eT>::fixed<fixed_n_elem>::fixed(const subview_cube<eT>& X)
 
 
 
+template<typename eT>
+template<uword fixed_n_elem>
+inline
+Col<eT>::fixed<fixed_n_elem>::fixed(const fill::scalar_holder<eT> f)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
+  {
+  arma_extra_debug_sigprint_this(this);
+  
+  (*this).fill(f.scalar);
+  }
+
+
+
 template<typename eT>
 template<uword fixed_n_elem>
 template<typename fill_type>
@@ -1526,6 +1585,7 @@ Col<eT>::fixed<fixed_n_elem>::operator=(const fixed<fixed_n_elem>& X)
 template<typename eT>
 template<uword fixed_n_elem>
 arma_inline
+arma_warn_unused
 const Op< typename Col<eT>::template fixed<fixed_n_elem>::Col_fixed_type, op_htrans >
 Col<eT>::fixed<fixed_n_elem>::t() const
   {
@@ -1537,6 +1597,7 @@ Col<eT>::fixed<fixed_n_elem>::t() const
 template<typename eT>
 template<uword fixed_n_elem>
 arma_inline
+arma_warn_unused
 const Op< typename Col<eT>::template fixed<fixed_n_elem>::Col_fixed_type, op_htrans >
 Col<eT>::fixed<fixed_n_elem>::ht() const
   {
@@ -1548,6 +1609,7 @@ Col<eT>::fixed<fixed_n_elem>::ht() const
 template<typename eT>
 template<uword fixed_n_elem>
 arma_inline
+arma_warn_unused
 const Op< typename Col<eT>::template fixed<fixed_n_elem>::Col_fixed_type, op_strans >
 Col<eT>::fixed<fixed_n_elem>::st() const
   {
